==> freecad_0.9.2646.5.orig.tar.gz: FreeCAD-0.9.2646/src/Tools/_TEMPLATE_/Gui/App_TEMPLATE_Gui.cpp <==
/***************************************************************************
 *   Copyright (c) YEAR YOUR NAME         <Your e-mail address>            *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#include "PreCompiled.h"
#ifndef _PreComp_
# include <Python.h>
#endif

#include <Base/Console.h>
#include <Gui/Application.h>

#include "Workbench.h"

// use a different name to CreateCommand()
void Create_TEMPLATE_Commands(void);


/* registration table  */
extern struct PyMethodDef _TEMPLATE_Gui_methods[];

PyDoc_STRVAR(module__TEMPLATE_Gui_doc,
"This module is the _TEMPLATE_Gui module.");


/* Python entry */
extern "C" {
void _TEMPLATE_GuiExport init_TEMPLATE_Gui()
{
    if (!Gui::Application::Instance) {
        PyErr_SetString(PyExc_ImportError, "Cannot load Gui module in console application.");
        return;
    }

    // instanciating the commands
    Create_TEMPLATE_Commands();
    _TEMPLATE_Gui::Workbench::init();

    // ADD YOUR CODE HERE
    //
    //

    (void) Py_InitModule3("_TEMPLATE_Gui", _TEMPLATE_Gui_methods, module__TEMPLATE_Gui_doc);   /* mod name, table ptr */
    Base::Console().Log("Loading GUI of _TEMPLATE_ module... done\n");

    return;
}

} // extern "C"

==> freecad-1.0.2.tar.gz: FreeCAD-1.0.2/src/Tools/_TEMPLATE_/Gui/App_TEMPLATE_Gui.cpp <==
/***************************************************************************
 *   Copyright (c) YEAR YOUR NAME <Your e-mail address>                    *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#include "PreCompiled.h"
#ifndef _PreComp_
#include <Python.h>
#endif

#include <Base/Console.h>
#include <Base/Interpreter.h>
#include <Base/PyObjectBase.h>
#include <Gui/Application.h>

#include "Workbench.h"

#include <CXX/Extensions.hxx>
#include <CXX/Objects.hxx>

// use a different name to CreateCommand()
void Create_TEMPLATE_Commands(void);


namespace _TEMPLATE_Gui
{
class Module: public Py::ExtensionModule<Module>
{
public:
    Module()
        : Py::ExtensionModule<Module>("_TEMPLATE_Gui")
    {
        initialize("This module is the _TEMPLATE_Gui module.");  // register with Python
    }

    virtual ~Module()
    {}

private:
};

PyObject* initModule()
{
    return Base::Interpreter().addModule(new Module);
}

}  // namespace _TEMPLATE_Gui


/* Python entry */
PyMOD_INIT_FUNC(_TEMPLATE_Gui)
{
    if (!Gui::Application::Instance) {
        PyErr_SetString(PyExc_ImportError, "Cannot load Gui module in console application.");
        PyMOD_Return(0);
    }

    // instantiating the commands
    Create_TEMPLATE_Commands();
    _TEMPLATE_Gui::Workbench::init();

    // ADD YOUR CODE HERE
    //
    //
    PyObject* mod = _TEMPLATE_Gui::initModule();
    Base::Console().Log("Loading GUI of _TEMPLATE_ module... done\n");
    PyMOD_Return(mod);
}
